DevicePropertyCode

Enum DevicePropertyCode 

#[repr(u16)]
pub enum DevicePropertyCode {
Show 33 variants Undefined = 20_480, BatteryLevel = 20_481, FunctionalMode = 20_482, ImageSize = 20_483, CompressionSetting = 20_484, WhiteBalance = 20_485, RgbGain = 20_486, FNumber = 20_487, FocalLength = 20_488, FocusDistance = 20_489, FocusMode = 20_490, ExposureMeteringMode = 20_491, FlashMode = 20_492, ExposureTime = 20_493, ExposureProgramMode = 20_494, ExposureIndex = 20_495, ExposureBiasCompensation = 20_496, DateTime = 20_497, CaptureDelay = 20_498, StillCaptureMode = 20_499, Contrast = 20_500, Sharpness = 20_501, DigitalZoom = 20_502, EffectMode = 20_503, BurstNumber = 20_504, BurstInterval = 20_505, TimelapseNumber = 20_506, TimelapseInterval = 20_507, FocusMeteringMode = 20_508, UploadUrl = 20_509, Artist = 20_510, CopyrightInfo = 20_511, Unknown(u16),
}
Standard PTP device property codes (0x5000 range).

These codes identify device-level properties that can be read or modified using the GetDevicePropDesc, GetDevicePropValue, SetDevicePropValue, and ResetDevicePropValue operations.

Device properties are primarily used with digital cameras for settings like ISO, aperture, shutter speed, etc. Most Android MTP devices do not support device properties.

Variants



Undefined = 20_480

Undefined property.



BatteryLevel = 20_481

Battery level (UINT8, 0-100 percent).



FunctionalMode = 20_482

Device functional mode (UINT16).



ImageSize = 20_483

Image size setting (String, e.g., “1920x1080”).



CompressionSetting = 20_484

Compression setting (UINT8).



WhiteBalance = 20_485

White balance (UINT16).



RgbGain = 20_486

RGB gain (String).



FNumber = 20_487

F-Number/Aperture (UINT16, value/100 = f-stop).



FocalLength = 20_488

Focal length (UINT32, units of 0.01mm).



FocusDistance = 20_489

Focus distance (UINT16, mm).



FocusMode = 20_490

Focus mode (UINT16).



ExposureMeteringMode = 20_491

Exposure metering mode (UINT16).



FlashMode = 20_492

Flash mode (UINT16).



ExposureTime = 20_493

Exposure time/shutter speed (UINT32, units of 0.0001s).



ExposureProgramMode = 20_494

Exposure program mode (UINT16).



ExposureIndex = 20_495

Exposure index/ISO (UINT16).



ExposureBiasCompensation = 20_496

Exposure bias compensation (INT16, units of 0.001 EV).



DateTime = 20_497

Date and time (String, “YYYYMMDDThhmmss”).



CaptureDelay = 20_498

Capture delay (UINT32, ms).



StillCaptureMode = 20_499

Still capture mode (UINT16).



Contrast = 20_500

Contrast (UINT8).



Sharpness = 20_501

Sharpness (UINT8).



DigitalZoom = 20_502

Digital zoom (UINT8).



EffectMode = 20_503

Effect mode (UINT16).



BurstNumber = 20_504

Burst number (UINT16).



BurstInterval = 20_505

Burst interval (UINT16, ms).



TimelapseNumber = 20_506

Timelapse number (UINT16).



TimelapseInterval = 20_507

Timelapse interval (UINT32, ms).



FocusMeteringMode = 20_508

Focus metering mode (UINT16).



UploadUrl = 20_509

Upload URL (String).



Artist = 20_510

Artist name (String).



CopyrightInfo = 20_511

Copyright info (String).



Unknown(u16)

Unknown/vendor-specific property code.